/**
 * The MIT License (MIT)

Copyright (c) 2013 Chute

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.chute.android.photopickerplus.ui.fragment;

import java.util.List;

import android.app.Activity;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.GridView;

import com.chute.android.photopickerplus.R;
import com.chute.android.photopickerplus.config.PhotoPicker;
import com.chute.android.photopickerplus.models.enums.LocalMediaType;
import com.chute.android.photopickerplus.ui.adapter.ServicesAdapter;
import com.chute.sdk.v2.model.enums.AccountType;

public class FragmentServices extends Fragment {

  private GridView gridViewServices;
  private ServicesAdapter adapter;
  private ServiceClickedListener serviceClickedListener;

  public interface ServiceClickedListener {

    public void accountLogin(AccountType accountType);

    public void photoStream();

    public void cameraRoll();

    public void lastPhoto();

    public void takePhoto();

  }

  public static FragmentServices newInstance(String[] services) {
    FragmentServices frag = new FragmentServices();
    Bundle args = new Bundle();
    frag.setArguments(args);
    return frag;
  }

  @Override
  public void onAttach(Activity activity) {
    super.onAttach(activity);
    serviceClickedListener = (ServiceClickedListener) activity;
  }

  @Override
  public View onCreateView(LayoutInflater inflater, ViewGroup container,
      Bundle savedInstanceState) {
    View view = null;
    view = inflater.inflate(R.layout.gc_fragment_services, container, false);
    gridViewServices = (GridView) view.findViewById(R.id.gcGridViewServices);
    gridViewServices.setNumColumns(getResources().getInteger(
        R.integer.grid_columns_services));
    return view;
  }

  @Override
  public void onViewCreated(View view, Bundle savedInstanceState) {
    super.onViewCreated(view, savedInstanceState);
    PhotoPicker singleton = PhotoPicker
        .getInstance();
    configureServices(singleton.getRemoteServices(), singleton.getLocalServices());
  }

  private void configureServices(List<AccountType> remoteServices,
      List<LocalMediaType> localServices) {
    adapter = new ServicesAdapter(getActivity(), remoteServices, localServices,
        serviceClickedListener);
    gridViewServices.setAdapter(adapter);
  }

}
